@@ -206,5 +206,5 @@ class gossip():
         except KeyboardInterrupt:
             self.logged()
             
-#if __name__ == "__main__":
-gossip().main()
+if __name__ == "__main__":
+    gossip().main()
